<span class="plugin_link"><a href="{{ link }}"{% if target %} target="{{ target }}"{% endif %} {% if css_classes %} class="{{ css_classes }}"{% endif %}{% if inline_styles %} style="{{ inline_styles }}"{% endif %}>{{ name }}</a></span>